#!/bin/sh
# must be run from the mauve directory
# classpath.jar and mauve.jar must exist in the current directory
# author: smckay@google.com (Steve McKay)

# define NO_WINE to a non-empty string value to skip the wine tests
# define NO_NATIVE to a non-empty string value to skip the native tests

VM_VERSION=${TEST_VERSION:-"1.5"}

# setup the environment to run a vm matching the one we're testing
# otherwise we get errors about mismatched class varsion
JAVA_HOME=${JAVA_HOME:-"/usr/local/buildtools/java/jdk1.5.0_06"}
#PATH="$JAVA_HOME/bin:$PATH"

# identify both wine and the windows vm we want to test
WINE=${WINE:-"$HOME/testing/wine/wine"}
WIN_VM=${WIN_VM:-"$HOME/.wine/drive_c/jre15/bin/java.exe"}
LIN_VM=${LIN_VM:-"$JAVA_HOME/bin/java"}

# slurp all excluded tests
EXCLUDES=$(for test in `cat excluded.tests`; do echo -n " -exclude $test"; done)

# define harness debug args if the port is defined
if test -n "$HARNESS_PORT"; then
  HDBG_ARGS="-Xdebug -Xrunjdwp:transport=dt_socket,server=y,suspend=y,address=$HARNESS_PORT"
fi

# define runproc debug args if the port is defined
if test -n "$RUNPROC_PORT"; then
  PDBG_ARGS="-Xdebug -Xrunjdwp:transport=dt_socket,server=y,suspend=y,address=$RUNPROC_PORT"
fi

function main() {

  if test -z "$1"; then
    echo "usage: ./runtests.sh <test ...>"> /dev/stderr
    exit 1
  fi

  if test ! -r "classpath.jar" -o ! -r "mauve.jar"; then
    echo "'classpath.jar' and/or 'mauve.jar' doesn't exist." > /dev/stderr
    exit
  fi

  for test in $@; do
    run_test "$test"
  done
}

function run_test() {

  local _path="$1"
  local _id=`echo $_path | sed -e 's/\/$//' -e 's/\//\./g' -e 's/gnu\.testlet\.//'`

  echo "[$_id]"

  if test -n "$NO_WINE" -a -n "$NO_NATIVE"; then
    echo "WARNING: No test platforms enabled!" > /dev/stderr
  fi

  if test -z "$NO_WINE"; then
    echo
    echo "== wine =="
    run_harness "wine" "$WINE" "$WIN_VM" "-Xmx1g $PDBG_ARGS"
  fi

  if test -z "$NO_NATIVE"; then
    echo
    echo "== native =="
    run_harness "native" "" "$LIN_VM" " $PDBG_ARGS"
  fi

  echo "Done testing '$_id'."

  echo
  echo "== summary =="
  generate_report "$_id"
}

function run_harness() {

  local _name="$1"
  local _vmprefix="$2" # might be empty
  local _vm="$3"
  local _vmarg="$4"

  # add the "-vmprefix" flag if the variable is non-zero length
  if test -n "$_vmprefix"; then
    _vmprefix="-vmprefix $_vmprefix"
  fi

  $LIN_VM -classpath ".:classpath.jar" \
      $HDBG_ARGS Harness -showpasses -compile false $EXCLUDES "$_path" \
      $_vmprefix -vm "$_vm" -vmarg "$_vmarg" \
      | tee "results/$_id-$VM_VERSION.$_name"
}

function generate_report() {
  local _id="$1"
  pushd results > /dev/null
  ./report.sh $_id
  popd > /dev/null
}

main $@

